# Credits to Matthew Callis for this macOS update script

#!/bin/bash

# macOS: Make sure to give execute permissions to the script (`chmod +x UPDATE.sh`) and you may need to install `avrdude` if you haven't with Homebrew (https://brew.sh/) `brew install avrdude`.
# Searching for device
port=$(ioreg -c IOSerialBSDClient -r | grep 'IOTTYDevice' | grep 'usbmodem' | awk -F'=' '{print $2}' | tr -d ' "' | sed 's/^/tty./')

echo "Searching for device"

# If port is empty, exit
if [ -z "$port" ]; then
  echo "Device not found."
  exit 1
fi

echo "Found device: $port"

# Set baud rate
# Note: macOS stty doesn't have explicit DTR control, plugging and unplugging may be required
stty -f /dev/$port 1200

# Run avrdude
avrdude -V -patmega4809 -cjtag2updi -P/dev/$port -b115200 -e -D "-Uflash:w:binary.hex:i" "-Ufuse2:w:0x01:m" "-Ufuse5:w:0xC9:m" "-Ufuse8:w:0x00:m"

# Prompt user
read -n 1 -s -r -p "Update completed. Press any key ..."

# Newline for cleanliness
echo
